# Amazon Inspector 2

It's a CDK construct to configure Amazon Inspector 2.

Current version supports enabling Amazon Inspector 2 and specify which resources types to enable.

## Install

TypeScript/JavaScript:

```shell
yarn add oblcc-amazon-inspector-2
```

or

```shell
npm install oblcc-amazon-inspector-2
```
